@@ -8,15 +8,16 @@ import datetime
 import logging
 from typing import Any, Dict, List, Optional
 
-from pydantic import BaseModel, Field
+from pydantic import Field
 
 from lunchable._config import APIConfig
+from lunchable.models._base import LunchableModel
 from lunchable.models._core import LunchMoneyAPIClient
 
 logger = logging.getLogger(__name__)
 
 
-class BudgetDataObject(BaseModel):
+class BudgetDataObject(LunchableModel):
     """
     Data Object within a Budget
     """
@@ -28,7 +29,7 @@ class BudgetDataObject(BaseModel):
     num_transactions: int = Field(default=0)
 
 
-class BudgetConfigObject(BaseModel):
+class BudgetConfigObject(LunchableModel):
     """
     Budget Configuration Object
     """
@@ -41,7 +42,7 @@ class BudgetConfigObject(BaseModel):
     auto_suggest: str
 
 
-class BudgetObject(BaseModel):
+class BudgetObject(LunchableModel):
     """
     Monthly Budget Per Category Object
 
@@ -50,19 +51,19 @@ class BudgetObject(BaseModel):
 
     _category_group_name_description = "Name of the category group, if applicable"
     _is_income_description = """
-    If true, this category is an income category (category properties 
+    If true, this category is an income category (category properties
     are set in the app via the Categories page)
     """
     _exclude_from_budget_description = """
-    If true, this category is excluded from budget (category 
+    If true, this category is excluded from budget (category
     properties are set in the app via the Categories page)
     """
     _exclude_from_totals_description = """
-    If true, this category is excluded from totals (category 
+    If true, this category is excluded from totals (category
     properties are set in the app via the Categories page)
     """
     _data_description = """
-    For each month with budget or category spending data, there is a data object with the key 
+    For each month with budget or category spending data, there is a data object with the key
     set to the month in format YYYY-MM-DD. For properties, see Data object below.
     """
     _config_description = """
@@ -71,7 +72,9 @@ class BudgetObject(BaseModel):
 
     category_name: str = Field(description="Name of the category")
     category_id: Optional[int] = Field(description="Unique identifier for category")
-    category_group_name: Optional[str] = Field(description=_category_group_name_description)
+    category_group_name: Optional[str] = Field(
+        description=_category_group_name_description
+    )
     group_id: Optional[int] = Field(description="Unique identifier for category group")
     is_group: Optional[bool] = Field(description="If true, this category is a group")
     is_income: bool = Field(description=_is_income_description)
@@ -81,7 +84,7 @@ class BudgetObject(BaseModel):
     config: Optional[BudgetConfigObject] = Field(description=_config_description)
 
 
-class BudgetParamsGet(BaseModel):
+class BudgetParamsGet(LunchableModel):
     """
     https://lunchmoney.dev/#get-budget-summary
     """
@@ -90,7 +93,7 @@ class BudgetParamsGet(BaseModel):
     end_date: datetime.date
 
 
-class BudgetParamsPut(BaseModel):
+class BudgetParamsPut(LunchableModel):
     """
     https://lunchmoney.dev/#upsert-budget
     """
@@ -101,7 +104,7 @@ class BudgetParamsPut(BaseModel):
     currency: Optional[str]
 
 
-class BudgetParamsRemove(BaseModel):
+class BudgetParamsRemove(LunchableModel):
     """
     https://lunchmoney.dev/#remove-budget
     """
@@ -110,13 +113,14 @@ class BudgetParamsRemove(BaseModel):
     category_id: int
 
 
-class _LunchMoneyBudgets(LunchMoneyAPIClient):
+class BudgetsClient(LunchMoneyAPIClient):
     """
     Lunch Money Budget Interactions
     """
 
-    def get_budgets(self, start_date: datetime.date,
-                    end_date: datetime.date) -> List[BudgetObject]:
+    def get_budgets(
+        self, start_date: datetime.date, end_date: datetime.date
+    ) -> List[BudgetObject]:
         """
         Get Monthly Budgets
 
@@ -129,18 +133,19 @@ class _LunchMoneyBudgets(LunchMoneyAPIClient):
         List[BudgetObject]
         """
         params = BudgetParamsGet(start_date=start_date, end_date=end_date).dict()
-        response_data = self._make_request(method="GET",
-                                           url_path=[APIConfig.LUNCHMONEY_BUDGET],
-                                           params=params)
+        response_data = self._make_request(
+            method="GET", url_path=[APIConfig.LUNCHMONEY_BUDGET], params=params
+        )
         budget_objects = [BudgetObject(**item) for item in response_data]
         return budget_objects
 
-    def upsert_budget(self,
-                      start_date: datetime.date,
-                      category_id: int,
-                      amount: float,
-                      currency: Optional[str] = None
-                      ) -> Optional[Dict[str, Any]]:
+    def upsert_budget(
+        self,
+        start_date: datetime.date,
+        category_id: int,
+        amount: float,
+        currency: Optional[str] = None,
+    ) -> Optional[Dict[str, Any]]:
         """
         Upsert a Budget for a Category and Date
 
@@ -173,18 +178,19 @@ class _LunchMoneyBudgets(LunchMoneyAPIClient):
         -------
         Optional[Dict[str, Any]]
         """
-        body = BudgetParamsPut(start_date=start_date, category_id=category_id,
-                               amount=amount, currency=currency).dict(exclude_none=True)
-        response_data = self._make_request(method="PUT",
-                                           url_path=[APIConfig.LUNCHMONEY_BUDGET],
-                                           payload=body)
+        body = BudgetParamsPut(
+            start_date=start_date,
+            category_id=category_id,
+            amount=amount,
+            currency=currency,
+        ).dict(exclude_none=True)
+        response_data = self._make_request(
+            method="PUT", url_path=[APIConfig.LUNCHMONEY_BUDGET], payload=body
+        )
 
         return response_data["category_group"]
 
-    def remove_budget(self,
-                      start_date: datetime.date,
-                      category_id: int
-                      ) -> bool:
+    def remove_budget(self, start_date: datetime.date, category_id: int) -> bool:
         """
         Unset an Existing Budget for a Particular Category in a Particular Month
 
@@ -200,8 +206,10 @@ class _LunchMoneyBudgets(LunchMoneyAPIClient):
         -------
         bool
         """
-        params = BudgetParamsRemove(start_date=start_date, category_id=category_id).dict()
-        response_data = self._make_request(method="DELETE",
-                                           url_path=[APIConfig.LUNCHMONEY_BUDGET],
-                                           params=params)
+        params = BudgetParamsRemove(
+            start_date=start_date, category_id=category_id
+        ).dict()
+        response_data = self._make_request(
+            method="DELETE", url_path=[APIConfig.LUNCHMONEY_BUDGET], params=params
+        )
         return response_data
