@@ -569,8 +569,8 @@ class TransactionsClient(LunchMoneyAPIClient):
         )
         return TransactionObject(**response_data)
 
-    ListOrSingleTransactionUpdateObject = Union[
-        TransactionUpdateObject, TransactionObject
+    ListOrSingleTransactionUpdateObject = Optional[
+        Union[TransactionUpdateObject, TransactionObject]
     ]
 
     ListOrSingleTransactionInsertObject = Union[
@@ -578,9 +578,7 @@ class TransactionsClient(LunchMoneyAPIClient):
         TransactionInsertObject,
         List[TransactionObject],
         List[TransactionInsertObject],
-        List[
-            Union[TransactionObject, TransactionInsertObject],
-        ],
+        List[Union[TransactionObject, TransactionInsertObject]],
     ]
 
     def update_transaction(
